// Copyright (c) 2021 Visiosto oy
// Licensed under the MIT License
var __read = (this && this.__read) || function (o, n) {
    var m = typeof Symbol === "function" && o[Symbol.iterator];
    if (!m) return o;
    var i = m.call(o), r, ar = [], e;
    try {
        while ((n === void 0 || n-- > 0) && !(r = i.next()).done) ar.push(r.value);
    }
    catch (error) { e = { error: error }; }
    finally {
        try {
            if (r && !r.done && (m = i["return"])) m.call(i);
        }
        finally { if (e) throw e.error; }
    }
    return ar;
};
import React from 'react';
import Terser from 'terser';
import { colorModeKey as defaultColorModeKey, initialColorModeCSSProp, } from '@visiosto/react-components';
// Thanks to Joshua Comeau for the original code, licensed under MIT License:
// https://github.com/joshwcomeau/dark-mode-minimal
// Don't use named function expression for this function just in case - this is embedded to the site
function setColorsByTheme() {
    var colors = '🌈';
    var colorModeKey = '🔑';
    var colorModeCssProp = '⚡️';
    var mediaQuery = window.matchMedia('(prefers-color-scheme: dark)');
    var prefersDarkScheme = mediaQuery.matches;
    var persistedPreference = localStorage.getItem(colorModeKey);
    var colorMode = 'light';
    // TODO Uncomment the line if a dark mode toggle is added
    // const hasUsedToggle = typeof persistedPreference === 'string';
    var hasUsedToggle = false;
    if (hasUsedToggle) {
        colorMode = persistedPreference;
    }
    else {
        colorMode = prefersDarkScheme ? 'dark' : 'light';
    }
    var root = document.documentElement;
    var invertedColorMode = colorMode === 'dark' ? 'light' : 'dark';
    root.style.setProperty(colorModeCssProp, colorMode);
    Object.entries(colors).forEach(function (_a) {
        var _b = __read(_a, 2), name = _b[0], colorByTheme = _b[1];
        var cssVarName = "--color-" + name;
        root.style.setProperty(cssVarName, colorByTheme[colorMode]);
        root.style.setProperty(cssVarName + "-inverted", colorByTheme[invertedColorMode]);
    });
}
function MagicScriptTag(_a) {
    var colors = _a.colors;
    var boundFn = String(setColorsByTheme)
        .replace("'🌈'", JSON.stringify(colors))
        .replace('🔑', defaultColorModeKey)
        .replace('⚡️', initialColorModeCSSProp);
    var calledFunction = "(" + boundFn + ")()";
    calledFunction = Terser.minify(calledFunction).code;
    // eslint-disable-next-line react/no-danger, react/jsx-filename-extension
    return React.createElement("script", { dangerouslySetInnerHTML: { __html: calledFunction } });
}
/**
 * If the user has JS disabled, the injected script will never fire!
 * This means that they won't have any colors set, everything will be default
 * black and white.
 * We can solve for this by injecting a `<style>` tag into the head of the
 * document, which sets default values for all of our colors.
 * Only light mode will be available for users with JS disabled.
 */
function FallbackStyles(_a) {
    // Create a string holding each CSS variable:
    /*
      `--color-text: black;
      --color-background: white;`
    */
    var colors = _a.colors;
    var cssVariableString = Object.entries(colors).reduce(function (acc, _a) {
        var _b = __read(_a, 2), name = _b[0], colorByTheme = _b[1];
        return acc + "\n--color-" + name + ": " + colorByTheme.light + ";\n--color-" + name + "-inverted: " + colorByTheme.dark + ";";
    }, '');
    var wrappedInSelector = "html { " + cssVariableString + " }";
    // eslint-disable-next-line react/jsx-filename-extension
    return React.createElement("style", null, wrappedInSelector);
}
// eslint-disable-next-line import/prefer-default-export
export var onRenderBody = function addColorThemeStylesOnRenderBody(_a, _b) {
    var setPreBodyComponents = _a.setPreBodyComponents, setHeadComponents = _a.setHeadComponents;
    var colors = _b.colors;
    setHeadComponents(React.createElement(FallbackStyles, { key: "color-scheme-fallback-styles", colors: colors }));
    setPreBodyComponents(React.createElement(MagicScriptTag, { key: "color-scheme-magic-script-tag", colors: colors }));
};
